@@ -39,8 +39,26 @@ def wait(secs=0):
 
 def login(driver, username, password):
     print("Logging in...")
-    driver.get("https://login.chumbacasino.com/")
+    driver.get("https://www.chumbacasino.com/")
 
+    try:
+        login_button = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.XPATH, "//*[contains(text(), 'Login')]")))
+        login_button.click()
+
+        username_box = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.NAME, "email")))
+        username_box.send_keys(username)
+
+        password_box = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.NAME, "password")))
+        password_box.send_keys(password)
+
+        wait(1)
+        password_box.send_keys(Keys.ENTER)
+        print("Logged in")
+    except TimeoutException:
+        print("Could not login")
+
+def relog(driver, username, password):
+    print("Trying to log in again...")
     try:
         username_box = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.NAME, "email")))
         username_box.send_keys(username)
@@ -48,13 +66,17 @@ def login(driver, username, password):
         password_box = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.NAME, "password")))
         password_box.send_keys(password)
 
+        wait(1)
         password_box.send_keys(Keys.ENTER)
         print("Logged in")
+        return True
     except TimeoutException:
-        print("Login boxes not found")
+        print("Could not login")
+        return False
 
 def close_modals(driver):
     try:
+        print("Finding daily bonus claim button")
         daily_bonus_button = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.ID, "daily-bonus__claim-btn")))
         daily_bonus_button.click()
         print("Daily bonus claimed")
@@ -63,7 +85,7 @@ def close_modals(driver):
 
     try:
         print("Finding offer close button")
-        offer_button = WebDriverWait(driver, 10).until(EC.element_to_be_clickable((By.ID, "offer__close")))
+        offer_button = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.ID, "offer__close")))
         offer_button.click()
         print("Offer closed")
     except TimeoutException:
@@ -81,25 +103,27 @@ def postal(driver, username, password):
         close_modals(driver)
         try:
             print("Finding table games button")
-            table_games_button = WebDriverWait(driver, 10).until(EC.element_to_be_clickable((By.ID, "TOP_HUD__table-games_link")))
+            table_games_button = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.ID, "TOP_HUD__table-games_link")))
             wait(2)
             table_games_button.click()
             print("Table games button")
         except TimeoutException:
-            print("Failed to table games button")
-            # driver.save_screenshot('screenie1.png')
-            raise
+            print("Failed to find table games button")
+            close_modals(driver)
+            if not relog(driver, username, password):
+                raise
 
         try:
             print("Finding footer button")
-            footer_button = WebDriverWait(driver, 10).until(EC.element_to_be_clickable((By.ID, "footer__postal-request-code")))
+            footer_button = WebDriverWait(driver, 5).until(EC.element_to_be_clickable((By.ID, "footer__postal-request-code")))
             wait(3)
             footer_button.click()
             print("Footer button clicked")
         except TimeoutException:
             print("Failed to find footer button")
-            # driver.save_screenshot('screenie1.png')
-            raise
+            close_modals(driver)
+            if not relog(driver, username, password):
+                raise
 
         try:
             print("Finding postal request button")
@@ -109,8 +133,9 @@ def postal(driver, username, password):
             print("Postal request button clicked")
         except TimeoutException:
             print("Failed to find postal request button")
-            # driver.save_screenshot('screenie5.png')
-            raise
+            close_modals(driver)
+            if not relog(driver, username, password):
+                raise
 
         # try:
         #     WebDriverWait(driver, 5).until(EC.presence_of_element_located((By.CSS_SELECTOR, "iframe[title='reCAPTCHA']")))
@@ -164,10 +189,11 @@ def postal(driver, username, password):
             print("Return button clicked")
         except TimeoutException:
             print("Failed to find return button")
-            # driver.save_screenshot('screenie6.png')
-            raise
+            close_modals(driver)
+            if not relog(driver, username, password):
+                raise
 
-        rand_time = random.randint(300, 420)
+        rand_time = random.randint(300, 436)
         cur_time = datetime.datetime.now()
         next_time = cur_time + datetime.timedelta(seconds=rand_time)
         print("Current time is ", cur_time.time(), ". Waiting until ", next_time.time())
